@@ -7,7 +7,7 @@
 # Gaspar Sinai <gaspar@yudit.org> Tokyo 2020-05-10
 #
 APPNAME=Yudit
-APPVERSION="3.0.9"
+APPVERSION="3.1.0"
 ARCH=$(uname -m)
 
 BUILD_NAME="unsigned"
@@ -35,7 +35,7 @@ export MACOSDIR="${DESTDIR}/${PREFIX}"
 
 mkdir -p $DESTDIR/Applications || check_error $? "Failed to create $DESTDIR/Applications/"
 ln -s /Applications/ $DESTDIR/Applications/Applications || check_error $? "Failed to create symlink"
-cp -R ./macos/Yudit.app $DESTDIR/Applications/ || check_error $? "Failed to copy to $DESTDIR/Applicaions/Yudit.app"
+cp -R ./macos/Yudit.app $DESTDIR/Applications/ || check_error $? "Failed to copy to $DESTDIR/Applications/Yudit.app"
 
 ./configure --prefix=${PREFIX} || check_error $? "configure failed."
 make -j 16 || check_error $? "make failed."
