@@ -124,7 +124,7 @@ SToolBar::SToolBar (const SProperties props)
   buttons[SS_MAGNIFY_MINUS] = new SButton (
        SIconFactory::getIcon("MagnifyMinus"), "A");
   buttons[SS_HIGHLIGHTING] = new SButton (
-       SIconFactory::getIcon("CheckStarted"), "H");
+       SIconFactory::getIcon("CheckStarted"), "N");
   //b = new SButton (translate ("Cut(&X)"), SIconFactory::getIcon("Cut"));
   unsigned int p=0;
   unsigned int h=0;
@@ -570,7 +570,7 @@ SToolBar::enterComponent (void* source)
       case SS_YIELD_EMBEDDING: str = translate ("__Y__ield Embedding"); break;
       case SS_MAGNIFY_MINUS: str = translate ("Smaller(__A__)"); break;
       case SS_MAGNIFY_PLUS: str = translate ("Bigger(__Z__)"); break;
-      case SS_HIGHLIGHTING: str = translate ("__H__ighlighting"); 
+      case SS_HIGHLIGHTING: str = translate ("Highlighting(__N__)"); 
         if (highlightName != "")
         {
           str.append (" ");
