@@ -24,6 +24,7 @@
 #include "stoolkit/SIO.h"
 #include "stoolkit/STypes.h"
 #include "stoolkit/SIOStream.h"
+#include "stoolkit/syntax/SSyntax.h"
 #include "swidget/SUniPrint.h"
 #include "swidget/SIconFactory.h"
 #include <swindow/SPrinter.h>
@@ -221,7 +222,7 @@ SYudit::SYudit (const SStringVector& args, const SProperties& props, const SStri
   slider = new SSlider ();
   slider->setLayout (sliderLayout);
   /* on mac somehow it did not want to resize - force it */
-  slider->resize (SDimension (getSliderWidth()/2, 200));
+  // slider->resize (SDimension (getSliderWidth()/2, 200));
   
   SString currentFont = toolbar->fonts[toolbar->currentFont];
   SString currentFontSize = toolbar->fontsizes[toolbar->currentFontSize];
@@ -994,7 +995,7 @@ SYudit::textEntered (void *source)
     save (cv, text);
     return;
   }
-  if (cv.size()>0 && cv[0] == "go")
+  if (cv.size()>0 && (cv[0] == "go" || cv[0] == "goto"))
   {
     goLineRow (cv, text);
     return;
@@ -1021,7 +1022,16 @@ SYudit::textEntered (void *source)
   if (cv.size() > 0 && cv[0] == "syntax")
   {
     SString smode;
-    if (cv.size() != 2)
+    if (cv.size() == 1)
+    {
+        SString lib = SSyntax::getLibraryLocation ();
+        if (lib.size()==0) lib = SString ("not-found");
+        SString message ("Hunspell: ");
+        message.append (lib);
+        messagelabel->setMessage (message, SMessageLabel::SS_INFO);
+        return;
+    }
+    if (cv.size() > 2 || cv[1] == "-h")
     {
       SString err = translate ("usage: ");
       err.append ("syntax none|simple|simple-dark|hunspell:en_US... ");
@@ -1405,7 +1415,7 @@ SYudit::load (const SStringVector& args, const SString& notused)
   }
   if (args[0] =="help" || helpStrings.get (args[0]) != 0)
   {
-    internal =  getDocDir();
+    internal =  getYuditDocDir();
     internal.append ("/");
 
     SString lang = getLanguage();
@@ -1435,7 +1445,7 @@ SYudit::load (const SStringVector& args, const SString& notused)
 
   if (args[0] =="howto" && args.size() >1)
   {
-    internal =  getDocDir();
+    internal =  getYuditDocDir();
     internal.append ("/");
     SString lang = getLanguage();
     if (helpStrings.get (args[0]) != 0) 
@@ -1467,7 +1477,7 @@ SYudit::load (const SStringVector& args, const SString& notused)
 
   if (args[0] =="test")
   {
-    internal =  getDocDir();
+    internal =  getYuditDocDir();
     internal.append ("/");
     internal.append ("TestPage.txt");
     i = args.size();
@@ -1694,7 +1704,7 @@ SYudit::decryptText (const SString& fileName, const SString& text, SString* out)
         return Failed;
     }
 //SGC
-//       fprintf (stderr, "Sedy: Successs\n");
+//       fprintf (stderr, "Sedy: Success\n");
     currentPassword = password;
     return Succeeded;
   } 
@@ -1816,7 +1826,7 @@ SYudit::save (const SStringVector& args, const SString& str)
     if (sedy.getLastError().size()) {
         text = SString("");
        //fprintf(stderr, "Sedy: %*.*s\n", SSARGS(sedy.getLastError()));
-        SString ems = translate ("Failded to set new password.");
+        SString ems = translate ("Failed to set new password.");
         messagelabel->setMessage (ems, SMessageLabel::SS_ERR);
         return;
     }
@@ -1825,7 +1835,7 @@ SYudit::save (const SStringVector& args, const SString& str)
     // Check if we can decrypt it.
     //dec.append ("makka");
     if (dec != text || sedy.getLastError().size()) {
-        SString ems = translate ("Failded to set new password.");
+        SString ems = translate ("Failed to set new password.");
         messagelabel->setMessage (ems, SMessageLabel::SS_ERR);
         return;
     }
@@ -2628,9 +2638,13 @@ bool
 SYudit::addMytoolPrefix (SString* executable)
 {
   if (executable->size()==0) return false;
+  SString pr = getBinDir();
 #ifdef USE_WINAPI
-  SString pr = getPrefix();
-  pr.append ("/bin/mytool.exe");
+  pr.append ("/mytool.exe");
+#else 
+  pr.append ("/mytool");
+#endif
+
   SFile f (pr);
   if (f.size () <= 0) 
   {
@@ -2643,35 +2657,7 @@ SYudit::addMytoolPrefix (SString* executable)
     messagelabel->setMessage (message, SMessageLabel::SS_ERR);
     return false;
   }
-#else
-  SString pr = getPrefix();
-  pr.append ("/bin/mytool");
-  SFile f0 (pr);
-  if (f0.size () <= 0) 
-  {
-    pr = getPrefix();
-    SStringVector pv(pr, "/");
-    if (pv.size() > 1)
-    {
-      pv.truncate (pv.size()-2);
-    }
-    pr = pv.join ("/");
-    pr.insert (0, "/");
-    pr.append ("/bin/mytool");
-    SFile f0 (pr);
-    if (f0.size () <= 0) 
-    {
-      SString message=translate ("Command not found: ");
-      message.append (SS_LB_LRE);
-      message.append ("'");
-      message.append (pr);
-      message.append ("'");
-      message.append (SS_LB_PDF);
-      messagelabel->setMessage (message, SMessageLabel::SS_ERR);
-      return false;
-    }
-  }
-#endif
+
   SStringVector v;
   v.smartSplit (*executable);
   if (!commandExists (v[0]))
