@@ -118,7 +118,7 @@ main (int argc, char* argv[])
     bool ret = false;
     if (d.exists() && d.readable())
     {
-      ret = setPrefix (pref);
+      ret = setProgramPrefix (pref);
     }
     else
     {
