@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -23,6 +23,7 @@
 #include "stoolkit/SString.h"
 #include "stoolkit/SIOStream.h"
 #include "stoolkit/SExcept.h"
+#include "stoolkit/STypes.h" 
 #include <string.h>
 #include <stdlib.h>
 
@@ -36,6 +37,7 @@
 
 // We will process lines with this length
 #define LINE_LENGTH 1024
+#define NEW_LINE_LENGTH (LINE_LENGTH+24)
 #define TOK_NAME   "NAME="
 #define TOK_COMM   "COMM="
 #define TOK_TYPE   "TYPE="
@@ -53,14 +55,14 @@
 
 /**
  * Prorcess a UNI file. Columns are separated by tabs or white spaces.
- * @param filename is the name of the iput file.
+ * @param filename is the name of the input file.
  * @param file is the input stream. It should be open, and it will not
  *        be closed at the end.
  * @param keysize is 0 for 8bit and 1 for 16 bit keys
  * @param hilo is 1 if we need to or local codes  with 0x8080 
  *        -1 if we need to and local codes with 0x7f7f.
  * @param from is the column from which coding happen.
- * @parem to is the column where the coded value is
+ * @param to is the column where the coded value is
  * @param reverse is nonzero to show that a reverse map should be built
  *        If reverse has been specified the role changes, so the same 
  *        from and to parameters result in a reverse (encoding)  map.
@@ -86,7 +88,7 @@ processUNI (const char* filename,  SInputStream& _fl, int nocomment, int keysize
   int    keyl=0;
   int    valuel=0;
   char    sectName [LINE_LENGTH+1];
-  char    newLine [LINE_LENGTH+24];
+  char    newLine [NEW_LINE_LENGTH+1];
   int    sectCommSize;
   int    posKey=0;
   int    posVle=0;
@@ -228,22 +230,22 @@ processUNI (const char* filename,  SInputStream& _fl, int nocomment, int keysize
     {
       if (reverse)
       {
-        sprintf (newLine, "%04X -> %02X ", parsedVle, parsedKey);
+        snprintf (newLine, NEW_LINE_LENGTH, "%04X -> %02X ", parsedVle, parsedKey);
       }
       else
       {
-        sprintf (newLine, "%02X -> %04X ", parsedKey, parsedVle);
+        snprintf (newLine, NEW_LINE_LENGTH, "%02X -> %04X ", parsedKey, parsedVle);
       }  
     }
     else
     {
       if (reverse)
       {
-        sprintf (newLine, "%04X -> %04X ", parsedVle, parsedKey);
+        snprintf (newLine, NEW_LINE_LENGTH, "%04X -> %04X ", parsedVle, parsedKey);
       }
       else
       {
-        sprintf (newLine, "%04X -> %04X ", parsedKey, parsedVle);
+        snprintf (newLine, NEW_LINE_LENGTH, "%04X -> %04X ", parsedKey, parsedVle);
       }  
     }
     if (!reverse && line[lend]=='#' && !nocomment)
@@ -268,7 +270,7 @@ processUNI (const char* filename,  SInputStream& _fl, int nocomment, int keysize
 
 /**
  * Prorcess a MYS  file. "local code -> unicode"
- * @param filename is the name of the iput file.
+ * @param filename is the name of the input file.
  * @param file is the input stream. It should be open, and it will not
  *        be closed at the end.
  * @param reverse is nonzero to show that a reverse map should be built
@@ -330,7 +332,9 @@ processMYS (const char* filename, SInputStream& _fl, int nocomment, int reverse,
     //
     if (section == -1 && strncmp (TOK_NAME, line, strlen(TOK_NAME)) == 0)
     {
-      strncpy (name, &line[strlen(TOK_NAME)], 32);
+      //strncpy (name, &line[strlen(TOK_NAME)], 32);
+      memcpy (name, &line[strlen(TOK_NAME)], 31);
+      name[31] = 0;
       continue;
     }
     if (section == -1 && strncmp (TOK_COMM, line, strlen(TOK_COMM)) == 0)
@@ -504,9 +508,9 @@ processMYS (const char* filename, SInputStream& _fl, int nocomment, int reverse,
 }
 
 /**
- * Prorcess a KMAP  file. "lcoal code =  unicode"
- * This came from UInput.cpp making that code obselete.
- * @param filename is the name of the iput file.
+ * Prorcess a KMAP  file. "local code =  unicode"
+ * This came from UInput.cpp making that code obsolete.
+ * @param filename is the name of the input file.
  * @param file is the input stream. It should be open, and it will not
  *        be closed at the end.
  * @param reverse is nonzero to show that a reverse map should be built
@@ -716,7 +720,8 @@ processKMap (const char* filename, SInputStream& _fl, int nocomment, int reverse
           segments[0], segments[1],
           segments[2], segments[3],
           segments[4], segments[5]);
-        if (segmentCount==0 && segmentCount > 5)
+        // FIXED && to ||
+        if (segmentCount==0 || segmentCount > 5)
         {
           error=1;
           break;
@@ -869,7 +874,7 @@ SBMapItemVector::~SBMapItemVector()
 
 /**
  * Adds a new line in kline format of InputMap
- * This came from UInput.cpp making that code obselete.
+ * This came from UInput.cpp making that code obsolete.
  * @param _index is the section index
  * @param _line is the quoted line
  * @param _comment is the comment.
