@@ -904,7 +904,7 @@ SParagraph::setParagraphSeparator (SS_ParaSep ps)
 
 
 /**
- * @return true if the visual ordering has beeen altered.
+ * @return true if the visual ordering has been altered.
  */
 bool
 SParagraph::isReordered () const
@@ -1052,6 +1052,10 @@ split (const SV_UCS4& ucs4, SVector<SGlyph>* gl, unsigned int from)
       du4.append (ucs4[i++]);
       // Prevent adding composing characters to it.
       break;
+    case SD_CD_LS:
+      du4.append (ucs4[i++]);
+      // Prevent adding composing characters to it.
+      break;
     default:
       isLineEnd = false;
       if (shaper.isOK())
