@@ -20,13 +20,16 @@
 #ifndef STypes_h
 #define STypes_h
 
-#define SD_YUDIT_VERSION "3.0.9"
+#define SD_YUDIT_VERSION "3.1.0"
 
 #define SB_YUDIT_MAX_SCALE 3.0
 
 /* search this many subdirectories */
 #define SB_YUDIT_SUBDIR_LEVEL 5
 
+// Speed tests: 5: 655ms 8: 1394ms / 1000 complex kanji.
+#define SS_RASTERIZER_OVERSAMPLE 8
+
 // Get the SS_WORD16_t and u_int_32
 #include <sys/types.h>
 #include "stoolkit/SBinVector.h"
