@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -18,6 +18,7 @@
  */
  
 #include "stoolkit/SUniqueID.h"
+#include "stoolkit/STypes.h" 
 #include "time.h"
 #include "string.h"
 
@@ -29,7 +30,7 @@ SUniqueID::SUniqueID(void)
    timePart = (unsigned int) t;
    sequence = oldSequence++;
    char a[64];
-   sprintf (a, "%u.%u", timePart, sequence);
+   snprintf (a, 64, "%u.%u", timePart, sequence);
    append (a, strlen (a));
 }
 
