@@ -43,6 +43,100 @@
 
 #include <string.h>
 
+
+#ifndef YUDIT_DATA
+#define YUDIT_DATA "/usr/share/yudit"
+#endif /* YUDIT_DATA  */
+
+#ifndef YUDIT_PREFIX
+#define YUDIT_PREFIX "/usr"
+#endif /* YUDIT_PREFIX  */
+
+#ifndef LOCALE_DIR
+#define LOCALE_DIR "/usr/share/locale"
+#endif /* LOCALE_DIR  */
+
+#ifndef BIN_DIR
+#define BIN_DIR "/usr/bin"
+#endif /* BIN_DIR  */
+
+#ifndef YUDIT_DOC_DIR
+#define YUDIT_DOC_DIR "/usr/share/doc/yudit"
+#endif /* YUDIT_DOC_DIR  */
+
+static SString getUnusualProgramPrefix ();
+
+// On Windows it is flat %INSTALLDIR% controlled by wininst.bat
+// On Mac it is expanded ProgramPrefix/share/yudit
+SString getYuditDataDir ()
+{
+    SString ret = getUnusualProgramPrefix();
+    // Linux and Mac local install and Windows failure
+    if (ret.size() == 0) {
+        return SString (YUDIT_DATA);
+    }
+    // Windows, Mac
+#ifdef USE_WINAPI
+    return SString (ret);
+#else 
+    ret.append ("/share/yudit");
+    return SString (ret);
+#endif
+}
+
+// On Windows it is flat %INSTALLDIR%\locale controlled by wininst.bat
+// On Mac it is expanded ProgramPrefix/share/locale
+SString getLocaleDir ()
+{
+    SString ret = getUnusualProgramPrefix();
+    // Linux and Mac local install and Windows failure
+    if (ret.size() == 0) {
+        return SString (LOCALE_DIR);
+    }
+    // Windows, Mac
+#ifdef USE_WINAPI
+    ret.append ("/locale");
+    return SString (ret);
+#else 
+    ret.append ("/share/locale");
+    return SString (ret);
+#endif
+
+}
+
+// On Windows it is flat %INSTALLDIR%\bin controlled by wininst.bat
+// On Mac it is expanded ProgramPrefix/bin
+SString getBinDir ()
+{
+    SString ret = getUnusualProgramPrefix();
+    // Linux and Mac local install and Windows failure
+    if (ret.size() == 0) { 
+        return SString (BIN_DIR);
+    }
+    // Windows, Mac
+    ret.append ("/bin");
+    return SString (ret);
+}
+
+// On Windows it is flat %INSTALLDIR%\doc controlled by wininst.bat
+// On Mac it is expanded ProgramPrefix/share/doc/yudit
+SString getYuditDocDir ()
+{
+    SString ret = getUnusualProgramPrefix();
+    // Linux and Mac local install and Windows failure
+    if (ret.size() == 0) {
+        return SString (YUDIT_DOC_DIR);
+    }
+    // Windows, Mac
+#ifdef USE_WINAPI
+    ret.append ("/doc");
+    return SString (ret);
+#else 
+    ret.append ("/share/yudit/doc");
+    return SString (ret);
+#endif
+}
+
 SString getHome ()
 {
 #ifdef USE_WINAPI
@@ -124,9 +218,6 @@ SString getHome ()
 #endif
 }
 
-#ifndef YUDIT_DATA
-#define YUDIT_DATA "/usr/share/yudit"
-#endif /* YUDIT_DATA  */
 
 #define YUDIT_MAX_DATA 2048
 
@@ -255,7 +346,8 @@ setReg (const SString& _base, const SString& _name, const SString& _vle)
 }
 #endif
 
-SString getPrefix ()
+/* Get a different install dir only on Windows and Mac */
+static SString getUnusualProgramPrefix ()
 {
 #ifdef USE_WINAPI
   SString akey = SString("Software\\Inui Yuko\\Yudit");
@@ -291,35 +383,34 @@ SString getPrefix ()
        SSARGS(key));
 #else
 # ifdef USE_OSX
-  
-  SDir dir("/Volumes/Yudit/Yudit.app/Contents/MacOS/share/yudit");
+  SDir dir("/Volumes/Yudit/Yudit.app/Contents/MacOS");
   if (dir.exists()) {
-    fprintf (stderr, "Using %*.*s as datadir instead of %s\n",
-      SSARGS(dir.getName()), YUDIT_DATA);
+    fprintf (stderr, "Using %*.*s as prefix instead of %s\n",
+      SSARGS(dir.getName()), YUDIT_PREFIX);
     return SString(dir.getName());
   } 
-  SString comp(YUDIT_DATA);
+  SString comp(YUDIT_PREFIX);
   SDir dir2(comp);
+ // This will tell to use LOCALE_DIR, YUDIT_DATA, BINDIR
   if (dir2.exists()) {
-    return SString(dir2.getName());
+    return SString("");
   }
   SString home = getHome();
-  home.append ("/Applications/Yudit.app/Contents/MacOS/share/yudit");
+  home.append ("/Applications/Yudit.app/Contents/MacOS");
   SDir dir3(home);
   if (dir3.exists()) {
     fprintf (stderr, "Using %*.*s as datadir instead of %s\n",
-      SSARGS(dir3.getName()), YUDIT_DATA);
+      SSARGS(dir3.getName()), YUDIT_PREFIX);
     return SString(dir3.getName());
   }
-  return SString(dir2.getName());
-
+ // This will tell to use LOCALE_DIR, YUDIT_DATA, BINDIR
+  return SString("");
 # endif
 #endif
-
-  return SString (YUDIT_DATA);
+  return SString ("");
 }
 
-bool setPrefix (const SString& str)
+bool setProgramPrefix (const SString& str)
 {
 #ifdef USE_WINAPI
   SString key = SString("Software\\Inui Yuko\\Yudit");
@@ -366,7 +457,7 @@ loadProperties (SProperties* in)
 {
   SString c1 = getHome();
   c1.append ("/.yudit/yudit.properties");
-  SString c2 = getPrefix();
+  SString c2 = getYuditDataDir();
   c2.append ("/config/yudit.properties");
 
   bool ret2 = loadProperties (c2, in);
@@ -956,28 +1047,9 @@ SStringVector getUserPath (const SString& property, const SString& directory) {
          outDataPath.append (vle);
       }
   }
-  SString c2 = getPrefix();
+  SString c2 = getYuditDataDir();
   c2.append ("/");
   c2.append (directory);
   outDataPath.append (c2);
   return SStringVector(outDataPath);
 } 
-
-SString getDocDir ()
-{
-    SString ret (getPrefix());
-    ret.append ("/doc");
-#if 0
-    SDir dir(ret);
-    if (!dir.readable()) {
-        SString fallback("/usr/share/doc/yudit");
-        fprintf (stderr, "Can not read: %*.*s Trying: %*.*s\n",   
-            SSARGS(ret), SSARGS(fallback));
-        SDir dir(fallback);
-        if (dir.readable()) {
-            ret = fallback;
-        }
-    }
-#endif
-    return SString(ret);
-}
