@@ -41,6 +41,12 @@ static void fixFileName (SString& str)
 }
 
 static void* dynHandle = 0;
+static SString libraryFilePath;
+
+SString
+SHunspellPattern::getLibraryLocation()  {
+    return SString(libraryFilePath);
+}
 
 SHunspellPattern::SHunspellPattern (const SString& _name, 
   const SStringVector& path)
@@ -200,6 +206,7 @@ SHunspellPattern::loadLibrary (const SStringVector& path)
       libFile = flib.getName();
       fixFileName (libFile);
     }
+    libraryFilePath = libFile;
     libFile.append ((char)0);
 #ifdef USE_WINAPI
     SEncoder u8("utf-8");
@@ -210,13 +217,17 @@ SHunspellPattern::loadLibrary (const SStringVector& path)
     if (!dynHandle) 
     {
       dynHandle = LoadLibraryA (libFile.array());
-      if (!dynHandle) return SString(ret);
+      if (!dynHandle) {
+        libraryFilePath.clear();
+        return SString(ret);
+      }
     }
 #else
     dynHandle = dlopen (libFile.array(), RTLD_LAZY);
     if (!dynHandle) 
     {
-      fprintf (stderr, "Can not open shared library %s\n", libFile.array());
+      //fprintf (stderr, "Can not open shared library %s\n", libFile.array());
+      libraryFilePath.clear();
       return SString(ret);
     }
 #endif
