@@ -27,6 +27,13 @@
 
 static SStringVector syntaxSearchPath;
 
+SString
+SSyntax::getLibraryLocation () {
+  SStringVector path = getPath();
+  SHunspellPattern::loadLibrary (path);
+  return SString(SHunspellPattern::getLibraryLocation()); 
+}
+
 SSyntax::SSyntax (void) : parser ("")
 {
   textData = 0;
