@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -40,10 +40,10 @@ SButtonListener::leaveComponent (void* source)
 
 /**
  * create a button.
- * @param autoacc indicates that the letter preceeded by '&'
+ * @param autoacc indicates that the letter preceded by '&'
  * should contain the accelerator.
  */
-SButton::SButton (const SString& string) : label (string) , back("white")
+SButton::SButton (const SString& string) : label (string) , border(SBorder::ETCHED),  back("white")
 {
   pressed = false;
   inside = false;
@@ -55,7 +55,7 @@ SButton::SButton (const SString& string) : label (string) , back("white")
 }
 
 SButton::SButton (SIcon* icon, const SString& accel) :
-  label ("", icon), back ("white")
+  label ("", icon), border(SBorder::ETCHED), back ("white")
 {
   pressed = false;
   inside = false;
@@ -68,11 +68,11 @@ SButton::SButton (SIcon* icon, const SString& accel) :
 
 /**
  * create a button.
- * @param autoacc indicates that the letter preceeded by '&'
+ * @param autoacc indicates that the letter preceded by '&'
  * should contain the accelerator.
  */
 SButton::SButton (const SString& string, SIcon* _icon) 
-  : label (string, _icon), back ("white")
+  : label (string, _icon), border(SBorder::ETCHED), back ("white")
 {
   pressed = false;
   inside = false;
@@ -199,7 +199,12 @@ SButton::resize (const SDimension& _size)
 void
 SButton::move (const SLocation& loc)
 {
+//fprintf (stderr, "Move from %d -> %d\n", getLocation().x, loc.x); 
   SPanel::move (loc);
+//if (location.x == 0) {
+//fprintf (stderr, " XXX Moving to location 0.\n");
+//}
+
 }
 
 void
@@ -209,6 +214,7 @@ SButton::recalcSize()
   SDimension dl = label.getPreferredSize();
   preferredSize = (db *2 ) + dl;
   label.move (SLocation (db.width, db.height));
+
 }
 
 void
