@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -105,6 +105,7 @@ SDialog::recalc ()
   SDimension db = yesButton->getPreferredSize();
   SDimension dn = noButton->getPreferredSize();
 
+
 //fprintf (stderr, "dialogPanel->getPreferredSize %u,%d\n",
 //    dl.width, dl.height);
 
@@ -118,46 +119,50 @@ SDialog::recalc ()
   //dl.width = dl.width + 20;
   //dl.height = dl.height + 20;
 
-  if (db.width + dn.width < 20)
+  unsigned int MGN = (unsigned int) (SAwt::getScale() * 5.0);
+  int OFFSCR = (int) (SAwt::getScale() * 100.0);
+
+  if (db.width + dn.width < 4*MGN)
   {
-    db.width = dn.width = 10;
+    db.width = dn.width = 2*MGN;
   }
 
-  if (db.width + 10 > dl.width)
+  if (db.width + 2*MGN > dl.width)
   {
-    dl.width = db.width + 10; 
+    dl.width = db.width + 2*MGN; 
   }
 
   preferredSize = SDimension (
-           dl.width + 10,
-           dl.height + db.height + 15);
+           dl.width + 2*MGN,
+           dl.height + db.height + 3*MGN);
 
 
   dialogPanel->setLayout (
     SLayout (
-       SLocation (5,5),
-       SLocation (dl.width+5, dl.height+5),
+       SLocation (MGN,MGN),
+       SLocation (dl.width+MGN, dl.height+MGN),
        SLocation (0,0),
        SLocation (100,100)
     )
   );
 
+  
 
   if (type != SS_QUESTION && type != SS_OK_CANCEL)
   {
     noButton->setLayout(
       SLayout (
-        SLocation (-200, -200),
-        SLocation (-100, -100)
+        SLocation (-OFFSCR*2, -OFFSCR*2),
+        SLocation (-100, -OFFSCR)
       )
     );
     //noButton->hide();
     yesButton->setLayout (
       SLayout (
-        SLocation (5 + ((int)dl.width)/2 - (int)db.width/2-1, 
-             (int)dl.height + 10),
-        SLocation (5 + ((int)dl.width)/2 + (int)db.width/2+1, 
-             (int)dl.height + 10 + (int) db.height),
+        SLocation (MGN + ((int)dl.width)/2 - (int)db.width/2-1, 
+             (int)dl.height + 2*MGN),
+        SLocation (MGN + ((int)dl.width)/2 + (int)db.width/2+1, 
+             (int)dl.height + 2*MGN + (int) db.height),
         SLocation (50,100),
         SLocation (50,100)
       )
@@ -168,20 +173,20 @@ SDialog::recalc ()
     //noButton->show();
     yesButton->setLayout (
       SLayout (
-        SLocation (5, 
-                 (int)dl.height + 10),
-        SLocation (5 + (int) db.width, 
-                  (int)dl.height + 10 + (int) db.height),
+        SLocation (MGN, 
+                 (int)dl.height + 2*MGN),
+        SLocation (MGN + (int) db.width, 
+                  (int)dl.height + 2*MGN + (int) db.height),
         SLocation (50,100),
         SLocation (50,100)
       )
     );
     noButton->setLayout (
       SLayout (
-        SLocation (5 + ((int)dl.width) - ((int)dn.width), 
-             (int)dl.height + 10),
-        SLocation (5 + ((int)dl.width), 
-             (int)dl.height + 10 + (int) db.height),
+        SLocation (MGN + ((int)dl.width) - ((int)dn.width), 
+             (int)dl.height + 2*MGN),
+        SLocation (MGN + ((int)dl.width), 
+             (int)dl.height + 2*MGN + (int) db.height),
         SLocation (50,100),
         SLocation (50,100)
       )
