@@ -1,7 +1,7 @@
 /** 
- *  Yudit Unicode Editor Source File
+ *  yudit unicode editor source file
  *
- *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
+ *  gNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -347,22 +347,6 @@ key==SWindowListener::Key_Shift_L)
   case SWindowListener::Key_F12:
     fKey (11, ctrl|shift|meta);
     break;
-  case SWindowListener::Key_B:
-  case SWindowListener::Key_b:
-    if (ctrl|meta)
-    {
-      if (ctrl && editorIF->isSelecting()) editorIF->endSelect();
-      editorIF->pageUp ();
-      break;
-    }
-  case SWindowListener::Key_C:
-  case SWindowListener::Key_c:
-   if (ctrl|meta)
-    {
-      if (editorIF->isSelecting()) editorIF->endSelect();
-      editorIF->clipSelect(false);
-      return; /* Automatic copy */
-    }
   /* This is used with accelerator anyway - this is never called here */
   case SWindowListener::Key_Y:
   case SWindowListener::Key_y:
@@ -371,6 +355,7 @@ key==SWindowListener::Key_Shift_L)
       editorIF->setDirection (SS_DR_L);
       break;
     }
+  /* This is used with accelerator anyway - this is never called here */
   case SWindowListener::Key_D:
   case SWindowListener::Key_d:
    if (ctrl|meta)
@@ -400,48 +385,74 @@ key==SWindowListener::Key_Shift_L)
       }
       break;
     }
+  // PAGE UP 
+  case SWindowListener::Key_B:
+  case SWindowListener::Key_b:
+    if (ctrl|meta)
+    {
+      if ((shift) && !editorIF->isSelecting()) { editorIF->startSelect(); }
+      //if (ctrl && editorIF->isSelecting()) editorIF->endSelect();
+      editorIF->pageUp ();
+      break;
+    }
+  // PAGE DOWN 
   case SWindowListener::Key_F:
   case SWindowListener::Key_f:
     if (ctrl|meta)
     {
-      if (ctrl && editorIF->isSelecting()) editorIF->endSelect();
+      // Allow selecting with shift
+      if ((shift) && !editorIF->isSelecting()) { editorIF->startSelect(); }
+      //if (ctrl && editorIF->isSelecting()) editorIF->endSelect();
       editorIF->pageDown ();
       break;
     }
+  // CURSOR LEFT 
   case SWindowListener::Key_H:
   case SWindowListener::Key_h:
     if (ctrl|meta)
     {
-      if (ctrl && editorIF->isSelecting()) editorIF->endSelect();
+      // Allow selecting with shift
+      if ((shift) && !editorIF->isSelecting()) { editorIF->startSelect(); }
+      //if (ctrl && editorIF->isSelecting()) editorIF->endSelect();
       editorIF->caretLeft ();
       break;
     }
-  case SWindowListener::Key_J:
-  case SWindowListener::Key_j:
-  case SWindowListener::Key_N:
-  case SWindowListener::Key_n:
-    if (ctrl||meta)
-    {
-      if (ctrl && editorIF->isSelecting()) editorIF->endSelect();
-      editorIF->caretDown ();
-      break;
-    }
-  case SWindowListener::Key_K:
-  case SWindowListener::Key_k:
-    if (ctrl|meta)
-    {
-      if (ctrl && editorIF->isSelecting()) editorIF->endSelect();
-      editorIF->caretUp ();
-      break;
-    }
+  // CURSOR RIGHT 
   case SWindowListener::Key_L:
   case SWindowListener::Key_l:
     if (ctrl||meta)
     {
-      if (ctrl && editorIF->isSelecting()) editorIF->endSelect();
+      // Allow selecting with shift
+      if ((shift) && !editorIF->isSelecting()) { editorIF->startSelect(); }
+      //if (ctrl && editorIF->isSelecting()) editorIF->endSelect();
       editorIF->caretRight ();
       break;
     }
+  // CURSOR DOWN 
+  case SWindowListener::Key_J:
+  case SWindowListener::Key_j:
+  /* Unefffective. Used by Syntax */
+  //case SWindowListener::Key_N:
+  //case SWindowListener::Key_n:
+    if (ctrl||meta)
+    {
+      // Allow selecting with shift
+      if ((shift) && !editorIF->isSelecting()) { editorIF->startSelect(); }
+      //if (ctrl && editorIF->isSelecting()) editorIF->endSelect();
+      editorIF->caretDown ();
+      break;
+    }
+  // CURSOR UP 
+  case SWindowListener::Key_K:
+  case SWindowListener::Key_k:
+    if (ctrl|meta)
+    {
+      // Allow selecting with shift
+      if ((shift) && !editorIF->isSelecting()) { editorIF->startSelect(); }
+      //if (ctrl && editorIF->isSelecting()) editorIF->endSelect();
+      editorIF->caretUp ();
+      break;
+    }
   case SWindowListener::Key_M:
   case SWindowListener::Key_m:
     if (ctrl|meta)
@@ -474,29 +485,48 @@ key==SWindowListener::Key_Shift_L)
       undo ();
       break;
     }
-  case SWindowListener::Key_v:
-  case SWindowListener::Key_V:
-    if (ctrl|meta)
+  case SWindowListener::Key_C:
+  case SWindowListener::Key_c:
+   if (ctrl|meta)
     {
       if (editorIF->isSelecting()) editorIF->endSelect();
-      pasteText (b, false);
-      return;
+      editorIF->clipSelect(false);
+      return; /* Automatic copy */
     }
   case SWindowListener::Key_X:
   case SWindowListener::Key_x:
     if (ctrl | meta)
     {
-      /* switch - delete */
       std = SUndo::SS_EraseSelect;
       editorIF->clipSelect(false);
       STextIndex mba = editorIF->getSelectedIndex(true);
+      ba = SCursorIndex (mba.line, mba.index);
+      erasedString = editorIF->eraseSelectedText();
+
+      if (erasedString.size() != 0)
+      {
+        a = editorIF->getCursorIndex();
+        add (SUndo(std, editorIF->getDirection (), embd, erasedString, b, a, ba));
+      } 
+      break;
+    }
+  case SWindowListener::Key_v:
+  case SWindowListener::Key_V:
+    if (ctrl|meta)
+    {
+      if (editorIF->isSelecting()) editorIF->endSelect();
+      // erase selected text and replace it with b
+      std = SUndo::SS_EraseSelect;  
+      STextIndex mba = editorIF->getSelectedIndex(true);
+      ba = SCursorIndex (mba.line, mba.index);
       erasedString = editorIF->eraseSelectedText();
-      if (cleared) return;
       if (erasedString.size() != 0)
       {
         a = editorIF->getCursorIndex();
         add (SUndo(std, editorIF->getDirection (), embd,  erasedString, b, a, ba));
+        b = editorIF->getCursorIndex();
       }
+      pasteText (b, false);
       break;
     }
   case SWindowListener::Key_Send:
