@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -45,7 +45,7 @@ public:
   virtual void setFont (const SString& font)=0;
   virtual void setInputMethod (const SString& im)=0;
 
-  virtual void insertClipboardText ()=0;
+  virtual void insertClipboardText (bool isPrimary)=0;
   virtual void insertText (const SString& str, bool embed=true)=0;
   virtual void insertDirtyText (const SString& str, bool embed=true)=0;
   virtual void insertPreEditText (const SString& utf8t, SPreEditor::SStyle style)=0;
@@ -65,7 +65,7 @@ public:
 
   virtual void startSelect ()=0;
   virtual void endSelect ()=0;
-  virtual void clipSelect ()=0;
+  virtual void clipSelect (bool isPrimary)=0;
 
   virtual void selectText (const SCursorIndex& till)=0; 
   virtual void selectWord ()=0;
