@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -17,15 +17,22 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include "swindow/SAwt.h"
 #include "swidget/SIcon.h"
 #include "stoolkit/SHashtable.h"
 
 typedef SHashtable<SImage> SImageCache;
 static SImageCache* imageCache=0;
 
+static int scaleInt (int value) {
+    return 1 + (int) (SAwt::getScale() * (double) value);
+}
+
 SIcon::SIcon (const SImage& _image) : image (_image)
 {
-  preferredSize = SDimension (image.getWidth(), image.getHeight());
+  preferredSize = SDimension (
+    scaleInt(image.getWidth()),
+    scaleInt (image.getHeight()));
 }
 
 /**
@@ -34,7 +41,10 @@ SIcon::SIcon (const SImage& _image) : image (_image)
  */
 SIcon::SIcon (const SString& _name) : image (1, 1, 1)
 {
-  preferredSize = SDimension (image.getWidth(), image.getHeight());
+  preferredSize = SDimension (
+    scaleInt(image.getWidth()),
+    scaleInt (image.getHeight()));
+
   if (imageCache == 0) imageCache = new SImageCache();
   const SImage* im = imageCache->get (_name);
   if (im==0)
@@ -45,7 +55,6 @@ SIcon::SIcon (const SString& _name) : image (1, 1, 1)
   {
     image = *im;
   }
-  preferredSize = SDimension (image.getWidth(), image.getHeight());
 }
 
 SIcon::~SIcon ()
@@ -65,7 +74,7 @@ SIcon::redraw (SCanvas* canvas)
   SVGBase * svgBase = image.getSVGBase();
   if (svgBase) {
     svgBase->setCanvas (canvas, background);
-    svgBase->render(getLocation().x, getLocation().y);
+    svgBase->render(getLocation().x, getLocation().y, SAwt::getScale());
   } else {
     canvas->putImage (getLocation().x, getLocation().y, image);
   }
