@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -162,4 +162,9 @@ SLabel::setAlignment (SAlignment _alignment)
 {
   label.setAlignment (_alignment);
   window->redraw (true, 0, 0, getSize().width, getSize().height);
-}
+} 
+void
+SLabel::changeStyle (SBorder::SStyle newStyle)
+{
+  border.changeStyle (newStyle);
+} 
