@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -16,12 +16,19 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-
 #include "swidget/SListBox.h"
-SListBox::SListBox (const SString& title)
+#include "swindow/SAwt.h"
+
+static int getSliderWidth () {
+//    return 20 * SAwt::getRasterScale();
+    return (int) (SAwt::getScale() * 20.0);
+}
+
+SListBox::SListBox (const SString& title) : border(SBorder::ETCHED) 
 {
  SPanel::forceLayout (SLayout (SDimension (1000,1000)));
  topLabel = new SLabel (title);
+// topLabel->changeStyle (SBorder::SOLID_VISIBLE);
  topLabel->setAlignment (SD_Center);
  textList = new STextList();
  slider = new SSlider();
@@ -34,6 +41,7 @@ SListBox::SListBox (const SString& title)
 void 
 SListBox::resize(const SDimension& d)
 {
+// fprintf (stderr, "XXX ListBox Panel %u,%u\n", d.width, d.height);
   border.resize(d);
   SPanel::resize (d);
 }
@@ -73,7 +81,7 @@ SListBox::recalc()
   int dheight = lh * 2;
   int dwidth = (int) topLabel->getPreferredSize().width + 2 * (int) bd.width;
 
-  if (dheight  < 20)dheight = 20;
+  if (dheight  < 20)dheight = 20 ;
   if (dwidth < 30) dwidth = 30;
   preferredSize = SDimension (dwidth, dheight);
 
@@ -86,7 +94,7 @@ SListBox::recalc()
     )
   );
 
-  int tw = (int)dwidth - 20 - (int) bd.width;
+  int tw = (int)dwidth - getSliderWidth() - (int) bd.width;
 
   textList->setLayout (
     SLayout (
@@ -99,7 +107,7 @@ SListBox::recalc()
   slider->setLayout (
     SLayout (
       SLocation (tw, lh+(int)bd.height),
-      SLocation (tw+20, (int)dheight - (int)bd.height),
+      SLocation (tw+getSliderWidth(), (int)dheight - (int)bd.height),
       SLocation (100, 0),
       SLocation (100, 100)
     )
