@@ -134,8 +134,8 @@ SSlider::SSlider (void) :
   set (SLocation (0,0), SDimension (0,0), SDimension (1,1), SDimension (0,0));
   slider.move (SLocation((int)border.getBorderSize().width, 
         (int)border.getBorderSize().height));
-  clip (true);
-  window->resize(10,10);
+//  clip (true);
+//  window->resize(10,10);
   dragOK = false;
   setSliderBackground (sliderBackground);
 }
@@ -148,11 +148,6 @@ void
 SSlider::redraw(SCanvas* w, int x, int y,
      unsigned int width ,unsigned int height)
 {
-  //fprintf (stderr, "redsize=%u,%u\n", size.width, size.height);
-  //fprintf (stderr, "redraw: me=%lx location=%d,%d size=%u,%u windowsize=%u,%u\n", 
-  //      (unsigned long) (SWindowListener*) this, 
-//x,  y, width ,height, w->getWidth(), w->getHeight());
-  
   clip (false);
   border.redraw (w, x, y, width, height);
   clip (true);
@@ -162,7 +157,10 @@ SSlider::redraw(SCanvas* w, int x, int y,
 void
 SSlider::resize (const SDimension& d)
 {
-  if (getSize() == d) return;
+  if (getSize() == d) 
+  {
+    return;
+  }
   SPanel::resize (d);
   border.resize (d);
 /*
@@ -177,12 +175,9 @@ SSlider::resize (const SDimension& d)
   }
 */
   clip (true);
-  // slider.resize (td);
   /* we are a panel */
   recalculateGeometry ();
   window->redraw(true, 0, 0, size.width, size.height);
-// fprintf (stderr, "XXX ListBox Slider %u,%u size=%u,%u\n", 
-//   d.width, d.height, size.width, size.height);
 }
 
 /**
@@ -231,16 +226,11 @@ SSlider::buttonPressed (SWindow * w, int button, int x, int y)
   /* see if we clicked the slider */
   if (l <  slider.getLocation()) 
   {
-//fprintf (stderr, "1: dragPoint=%d,%d slider=%d,%d\n",
- // l.x, l.y, slider.getLocation().x, slider.getLocation().y);
      dragOK = false;
      page (-1);
   }
   if (l >  slider.getLocation() + slider.getSize()) 
   {
-//fprintf (stderr, "2: dragPoint=%d,%d slider=%d,%d %u %u\n",
- // l.x, l.y, slider.getLocation().x, slider.getLocation().y,
-  //    slider.getSize().width, slider.getSize().height);
      dragOK = false;
      page (1);
   }
@@ -265,8 +255,6 @@ SSlider::buttonDragged (SWindow * w, int button, int x, int y)
   SLocation newValue = (l * slidable.max) / gmax;
   newValue = newValue.minimize(SLocation (0,0)).maximize(slidable.max);
   if (newValue == slidable.value) return;
-  //fprintf (stderr, "old=%d,%d new=%d,%d\n", 
-  //  value.x, value.y, newValue.x, newValue.y);
   slidable.value = newValue;
   slide (true);
 }
@@ -280,8 +268,6 @@ SSlider::page (int count)
   SLocation newValue = slidable.value + slidable.page * count;
   newValue = newValue.minimize(SLocation (0,0)).maximize(slidable.max);
   if (newValue == slidable.value) return;
-  //fprintf (stderr, "old=%d,%d new=%d,%d\n", 
-  //  value.x, value.y, newValue.x, newValue.y);
   slidable.value = newValue;
   slide (true);
 }
