@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -115,7 +115,7 @@ public:
   virtual void setFont (const SString& font);
   virtual void setInputMethod (const SString& im);
 
-  virtual void insertClipboardText ();
+  virtual void insertClipboardText (bool isPrimary);
   virtual void insertText (const SString& str, bool embed=true);
   virtual void insertDirtyText (const SString& str, bool embed=true);
   virtual void insertPreEditText (const SString& utf8t, 
@@ -137,7 +137,7 @@ public:
 
   virtual void startSelect ();
   virtual void endSelect ();
-  virtual void clipSelect ();
+  virtual void clipSelect (bool isPrimary);
 
   virtual void selectText (const SCursorIndex& till); 
   virtual void selectWord ();
