@@ -67,8 +67,8 @@ timerStop()
 static unsigned int sane_index (const SV_UINT& array, unsigned int index);
 
 
-static double scaleFontSize (bool scaleable, double _fontSize) {
-    if (!scaleable) return _fontSize;
+static double scaleFontSize (bool scalable, double _fontSize) {
+    if (!scalable) return _fontSize;
     double ret = SAwt::getScale() * _fontSize;   
     return ret;
 }
@@ -76,12 +76,12 @@ static double scaleFontSize (bool scaleable, double _fontSize) {
 /**
  * The text data is mine. I'll delete it.
  */
-STextView::STextView (bool _scaleable)
+STextView::STextView (bool _scalable)
   : lrpen (SColor (0.0, 0.0, 0.0, 1.0)),
   rlpen (SColor (0.0, 0.0, 1.0, 1.0)),
   underlineColor("red")
 {
-  scaleable = _scaleable;
+  scalable = _scalable;
   isHidingText = false;
   printerPageSize = 0;
   highlightMode = "";
@@ -104,12 +104,12 @@ STextView::STextView (bool _scaleable)
  * Make a text-view from external text
  * @param utf8 is the utf8 ancoded text
  */
-STextView::STextView (const SString& utf8, bool _scaleable)
+STextView::STextView (const SString& utf8, bool _scalable)
   : textData (utf8), lrpen (SColor (0.0, 0.0, 0.0, 1.0)),
   rlpen (SColor (0.0, 0.0, 1.0, 1.0)),
   underlineColor("red")
 {
-  scaleable = _scaleable;
+  scalable = _scalable;
   isHidingText = false;
   printerPageSize = 0;
   highlightMode = "";
@@ -173,7 +173,7 @@ STextView::setClippingArea (int _x, int _y,
 void
 STextView::setFont (const SString& _font, double _fontSize)
 {
-  if (_fontSize > 0.0) fontSize = scaleFontSize (scaleable, _fontSize);
+  if (_fontSize > 0.0) fontSize = scaleFontSize (scalable, _fontSize);
   font = SFont(_font, fontSize);
   setPen ();
   setReordered ();
@@ -191,7 +191,7 @@ STextView::setFont (const SString& _font, double _fontSize)
 void
 STextView::setFontSize (double _fontSize)
 {
-  if (_fontSize > 0.0) fontSize = scaleFontSize (scaleable, _fontSize);
+  if (_fontSize > 0.0) fontSize = scaleFontSize (scalable, _fontSize);
   font.setSize(fontSize);
   
   setPen ();
@@ -360,7 +360,7 @@ STextView::getCursorIndex (const SLocation& l)
   if (i<brk.size()) nextExt = brk[i];
   // SGC bool endsline = false;
 
-  /* find the x position witihn the line */
+  /* find the x position within the line */
   SCursorIndex cindex (line, currExt);
   bool llr = textData.isLR(line);
   bool before = true;
@@ -447,7 +447,7 @@ STextView::getTextLocation (const STextIndex& textIndex, bool before)
     int si = 0;
     if (index < textData.size(line))
     {
-       /* convert logical 'before' to phisical */ 
+       /* convert logical 'before' to physical */ 
        bool glr = textData.isLR(STextIndex(line, index));
        bool llr = textData.isLR(line);
 
@@ -1399,7 +1399,7 @@ STextView::wrapAndPosition (unsigned int from, unsigned int until, int addcount)
 }
 
 /**
- * Caclulate the extent as one line.
+ * Calculate the extent as one line.
  * It inserts an element at line in positions, and breaks.
  * The positions array will have the positions of the end
  * of the glyph, ragrdless of paragraph embedding, in LR order. 
