@@ -38,8 +38,8 @@ typedef SBinHashtable<SS_UINT> SH_UINT;
 class STextView : public SComponent, STextDataListener
 {
 public:
-  STextView (bool scaleable=true);
-  STextView (const SString& utf8, bool scaleable=true);
+  STextView (bool scalable=true);
+  STextView (const SString& utf8, bool scalable=true);
   virtual ~STextView ();
 
   /* Every component has this. */
@@ -122,7 +122,7 @@ private:
   bool              isEditable;
   bool              isHidingText;
   unsigned int      printerPageSize;
-  bool              scaleable;
+  bool              scalable;
 
   SCursorIndex moveCursor (const SCursorIndex& ci, bool up);
    
