@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -18,6 +18,7 @@
  */
 
 #include "stoolkit/SString.h"
+#include "stoolkit/STypes.h" 
 #include "swindow/SPrinter.h"
 #include "swidget/STextView.h"
 #include "swidget/SUniPrint.h"
@@ -30,7 +31,11 @@
 SUniPrint::SUniPrint (const SPrinter& _printer, 
            const SString& headerFontName,  double headerFontSize,
            const SString& bodyFontName,  double bodyFontSize) :
-    printer (_printer)
+    printer (_printer),
+    body(false),
+    headerLeft(false),
+    headerCenter(false),
+    headerRight(false)
 {
   pageCount = 0;
   printheader = (headerFontSize > 1.0);
@@ -109,7 +114,7 @@ SUniPrint::print (const SString& header, const SString& buffer, bool evt)
   /* FIXME: break it into pages, and set the viewport */
   /* first print to cache. */
 
-  /* cahce the top line */
+  /* cache the top line */
   SLocation l (body.getLocation().x, body.getLocation().y);
   SDimension d = body.getSize();
 
@@ -153,7 +158,7 @@ SUniPrint::print (const SString& header, const SString& buffer, bool evt)
 
     char a[64];
     /* we are not much off using current page */
-    sprintf (a, "Page %u of %u", pageCount, pageCount);
+    snprintf (a, 64, "Page %u of %u", pageCount, pageCount);
     headerRight.setText (a);
     SDimension rd = headerRight.getPreferredSize ();
     headerRight.resize (rd);
@@ -261,7 +266,7 @@ SUniPrint::print (const SString& header, const SString& buffer, bool evt)
     /* right aligned header */
     pageCount++;
     char a[64];
-    sprintf (a, "Page %u of %u", pageCount, fullPageCount);
+    snprintf (a, 64, "Page %u of %u", pageCount, fullPageCount);
     headerRight.setText (a);
     SDimension rd = headerRight.getPreferredSize ();
 
