@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -18,6 +18,7 @@
  */
  
 #include "swindow/SFontFB.h"
+#include "stoolkit/STypes.h" 
 #include <stdio.h>
 /**
  * The following is from freeware 'dixon.zip' font at 
@@ -895,7 +896,7 @@ SFontFB::signDraw (SCanvas* canvas, const SPen& pen,
 
   char a[64];
  
-  sprintf (a, "sign=%d\n", (int) sign);
+  snprintf (a, 64, "sign=%d\n", (int) sign);
   SString key (a);
   key.append ((long)(matrix.x0*16000.0));
   key.append ((long)(matrix.y1*16000.0));
@@ -964,14 +965,14 @@ SFontFB::draw (SCanvas* canvas, const SPen& pen,
   SS_Matrix2D r;
   char a[64];
   /* FIXME: you should in fact use an instance counter. */
-  sprintf (a, "%lx ", (unsigned long) this);
+  snprintf (a, 64, "%lx ", (unsigned long) this);
   SString key (a);
-  sprintf (a, "%ul;", g);
+  snprintf (a, 64, "%ul;", g);
   key.append (a);
   /* Get the scale factor */
   char wh[64];
   SS_Matrix2D mtrx = canvas->getCurrentMatrix() * matrix;
-  sprintf (wh, "scale=%g,%g;", mtrx.x0, mtrx.y1);
+  snprintf (wh, 64, "scale=%g,%g;", mtrx.x0, mtrx.y1);
   key.append (wh);
   SColor fg = pen.getForeground();
   key.append ("fg:");
