@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -31,6 +31,7 @@
 #include "stoolkit/SExcept.h"
 #include "stoolkit/SUtil.h"
 #include "stoolkit/SCluster.h"
+#include "stoolkit/STypes.h" 
 
 static SStringVector fontSearchPath(
    "/,fonts,../fonts,/etc/fonts,/usr/share/yudit/fonts");
@@ -401,64 +402,22 @@ SFontImpl::setPath(const SStringVector& l)
   fontSearchPath = l;
 }
 
+const SStringVector&
+SFontImpl::getPath()
+{
+    return fontSearchPath;
+}
+
 /**
  * search files for property in order and set the path to the 
  * property. Always add YUDIT_DATA/fonts
  */
 void
-SFontImpl::guessPath (const SStringVector& files, const SString& property)
+SFontImpl::guessPath ()
 {
-  
-  SStringVector outDataPath;
-
-  for (unsigned int i=0; i<files.size(); i++)
-  {
-    SProperties p;
-    loadProperties (files[i], &p);
-    if (p.get (property))
-    {
-      SStringVector v(p[property], ",:;");
-      for (unsigned int j=0; j<v.size(); j++)
-      {
-         outDataPath.append (v[j]);
-      }
-    }
-  }
-  SString c1 = getHome();
-  c1.append ("/.yudit/fonts");
-  SString c2 = getPrefix();
-  c2.append ("/fonts");
-  if (outDataPath.size()!=0)
-  { 
-    outDataPath.append (c1); 
-    outDataPath.append (c2); 
-    fontSearchPath = outDataPath;
-  }
-  else
-  {
-    outDataPath.append (c1); 
-    outDataPath.append (c2); 
-    outDataPath.append (fontSearchPath);
-    fontSearchPath = outDataPath;
-  }
-//fprintf (stderr, "fontpath is %*.*s\n", SSARGS(fontSearchPath.join(",")));
+  fontSearchPath = getUserPath ("yudit.fontpath", "fonts");
+  //fprintf (stderr, "fontpath is %*.*s\n", SSARGS(fontSearchPath.join(",")));
 }
-/**
- * get the path using the "yudit.default.path"
- */
-void
-SFontImpl::guessPath()
-{
-  SString c1 = getHome();
-  c1.append ("/.yudit/yudit.properties");
-  SString c2 = getPrefix();
-  c2.append ("/config/yudit.properties");
-  SStringVector v;
-  v.append (c1);
-  v.append (c2);
-  guessPath (v, "yudit.fontpath");
-}
-
 /**
  * Scale the font to the given pointsize.
  * @param x is the x axis pointsize
@@ -492,7 +451,7 @@ SFontImpl::scale (double x, double y)
     */
     if (d->u.native==0) break;
     l.split (xlfd, "-");
-    sprintf (tmp, "%u", (unsigned int) (y + 0.5));
+    snprintf (tmp, 64, "%u", (unsigned int) (y + 0.5));
     if (l.size() < 14)
     {
       fprintf (stderr, "BAD XLFD %*.*s\n", SSARGS(xlfd));
@@ -628,7 +587,7 @@ fprintf (stderr, "ascent: %g descent: %g offsetX: %g, offsetY: %g\n",
  * @param m is the conversion matrix
  * @param uch is the array containing ucs4 
  * @prama len is the length of the array
- * @return ture if it has width.
+ * @return true if it has width.
  *  width_ will be set t width if exists.
  */
  
@@ -846,6 +805,7 @@ SFontImpl::needSoftMirror (SS_UCS4 uch, bool isLRContext) const
   if (isRL() && isLRContext) return true;
   if (isLR() || isRL()) return false;
 
+
   if (getPUARovasType (uch) > 0) return !isLRContext;
   if (getRovasType (uch) > 0) return isLRContext;
   // rest is LR, need mirroring in RL context.
