@@ -738,13 +738,13 @@ SPostscript::bitfont (const SPen& pen, double x, double y,
   SX11Impl* impl=(SX11Impl*) SAwt::getDelegate();
   if (impl == 0)
   {
-    fprintf (stderr, "(impl) no luck in prining bitmap font.\n");
+    fprintf (stderr, "(impl) no luck in printing bitmap font.\n");
     return;
   }
   Window aWindow = (Window) impl->getAnyWindow();
   if (aWindow==None)
   {
-    fprintf (stderr, "(window) no luck in prining bitmap font.\n");
+    fprintf (stderr, "(window) no luck in printing bitmap font.\n");
     return;
   }
 
@@ -783,7 +783,7 @@ SPostscript::bitfont (const SPen& pen, double x, double y,
   {
     fill (pen);
     endImage();
-    fprintf (stderr, "(Pixmap) no luck in prining bitmap font.\n");
+    fprintf (stderr, "(Pixmap) no luck in printing bitmap font.\n");
     return;
   }
   XGCValues   gcv;
@@ -801,7 +801,7 @@ SPostscript::bitfont (const SPen& pen, double x, double y,
   XFreeGC (impl->display, gc);
   if (im==0)
   {
-    fprintf (stderr, "(Image) no luck in prining bitmap font.\n");
+    fprintf (stderr, "(Image) no luck in printing bitmap font.\n");
     fill (pen);
     endImage();
     return;
