@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -51,11 +51,11 @@ public:
 
   bool open (bool background);
   void newPage();
-  bool cacheOn (bool on=true); 
   bool close ();
   bool hasNative () const;
 
   /* From SCanvas */
+  virtual bool cacheOn (bool on=true); 
   virtual bool beginImage (double x, double y, const SString& id, const SColor& background);
   virtual void newpath ();
   virtual void endImage ();
@@ -78,9 +78,13 @@ public:
   virtual void bitline (const SColor& fg, int x, int y, int tox, int toy);
   virtual void bitpoint (const SColor& fg, int x, int y);
   virtual void bitpoints (const SColor& fg, const int* x, const int* y, 
-         unsigned int size);
+         unsigned int arraySize);
   SString getCreationDate() const;
 
+  virtual SS_Matrix2D  getCurrentMatrix() const;
+  virtual void putImage (int x, int y, const SImage& image);
+  virtual void setBackground(const SColor &color);
+
   /* for background */
   bool timeout (const SEventSource* s);  
 
@@ -114,6 +118,11 @@ private:
   double        cacheOriginX;
   double        cacheOriginY;
   SString       creationDate;
+
+protected:
+  /* From canvas. */
+  bool isCacheOn;
+
 };
 
 #endif /* SPostscript_h */
