@@ -211,7 +211,7 @@ SRasterizer::splitBezier (SRenderPathList* out, double x0, double y0, double x1,
 
     double delta2 = (x3 - x0) * (x3 - x0) + (y3 - y0) * (y3 - y0);
     
-    if (delta2 < 0.125  || iteration <= 0) {
+    if (delta2 < (1.0/32.0)  || iteration <= 0) {
         // lineto without matrix.
         out->append (x3, y3);
         return;
@@ -348,7 +348,7 @@ fprintf (stderr, "Offscreen newMinY=%d newImageY=%d height=%d newMaxY=%d\n", new
 
         int run = (int) y0;
         int finish = (int) y1;
-        // Move y off the grid 1/64 - 6 bit, alowing 64 oversample.
+        // Move y off the grid 1/64 - 6 bit, allowing 64 oversample.
         if (y0 == (double) run) y0 = y0 + (1.0/64.0);
         if (y1 == (double) finish) y1 = y1 + (1.0/64.0);
         int increment = (y0 < y1) ? 1 : -1;
@@ -464,7 +464,7 @@ fprintf (stderr, "Offscreen newMinY=%d newImageY=%d height=%d newMaxY=%d\n", new
 
         int run = (int) x0;
         int finish = (int) x1;
-        // Move y off the grid 1/64 - 6 bit, alowing 64 oversample.
+        // Move y off the grid 1/64 - 6 bit, allowing 64 oversample.
         if (x0 == (double) run) x0 = x0 + (1.0/64.0);
         if (x1 == (double) finish) x1 = x1 + (1.0/64.0);
         int increment = (x0 < x1) ? 1 : -1;
@@ -573,7 +573,7 @@ SRasterizer::strokeInternal (double lineWidth, unsigned int maxWidth,unsigned in
     LineJoiner strokeJoiner (this, &strokeRenderPath, lineWidth, LineJoiner::BEVEL);
 
     const SRenderPathElement* el = renderPath.getHead(); 
-    // Walk through the outside of the poligons.
+    // Walk through the outside of the polygons.
     while (el) {
         if (!el->isClosedPath() || el->begin != el) {
             el = el->next;
@@ -601,7 +601,7 @@ SRasterizer::strokeInternal (double lineWidth, unsigned int maxWidth,unsigned in
         strokeRenderPath.closepath();
         el = el->next;
     }
-    // walk through the inside of the poligon.
+    // walk through the inside of the polygons.
     el = renderPath.getTail(); 
     while (el) {
         if (!el->isClosedPath() || el->begin->end != el) {
@@ -631,7 +631,7 @@ SRasterizer::strokeInternal (double lineWidth, unsigned int maxWidth,unsigned in
         el = el->prev;
     }
     el = renderPath.getHead(); 
-    // Do lines that are not closed paths.
+    // Draw lines that are not closed paths.
     while (el) {
         if (el->isClosedPath() || el->begin != el) {
             el = el->next;
@@ -668,7 +668,7 @@ SRasterizer::strokeInternal (double lineWidth, unsigned int maxWidth,unsigned in
 void
 LineJoiner::joinLoop (double x0, double y0, double x1, double y1, double x2, double y2, bool isBegin) {
     double minDelta = 1e-10;
-    // perpendicular vectors of lenth linewidth
+    // perpendicular vectors of length linewidth
     double v0x = y0-y1;
     double v0y = x1-x0;
     double v0l = sqrt (v0x*v0x + v0y* v0y);
