@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -20,6 +20,7 @@
 #include "swindow/SUniFont.h"
 #include "stoolkit/SCluster.h"
 #include "stoolkit/SBinVector.h"
+#include "stoolkit/STypes.h" 
 
 #include <stdlib.h>
 #include <string.h>
@@ -49,11 +50,11 @@ SUniFont::draw (double scale, SCanvas* canvas, const SColor& fg,
   int scriptCode = getLigatureScriptCode (g); 
   /* only support SD_AS_SHAPES if scriptCode */
   if (scriptCode != SD_AS_SHAPES && scriptCode >= 0) return false;
-  if ((int)scale != 16) return false;
+  //if ((int)scale != 16) return false;
   double w;
 
   unsigned int posw;
-  bool re =  width (scale, g, &w, &posw);
+  bool re =  width (16, g, &w, &posw);
   if (!re) return re;
 
   unsigned int pt = SD_GET_POS (posw);
@@ -195,23 +196,23 @@ SUniFont::find (SS_UCS4 g)
   /* colon is part of it */
   if (g <= 0xffff)
   {
-    sprintf (arr, "%04X:", g);
+    snprintf (arr, 32, "%04X:", g);
   }
   else if (g <= 0xfffff)
   {
-    sprintf (arr, "%05X:", g);
+    snprintf (arr, 32, "%05X:", g);
   }
   else if (g <= 0xffffff)
   {
-    sprintf (arr, "%06X:", g);
+    snprintf (arr, 32, "%06X:", g);
   }
   else if (g <= 0xfffffff)
   {
-    sprintf (arr, "%07X:", g);
+    snprintf (arr, 32, "%07X:", g);
   }
   else if (g <= 0x7fffffff)
   {
-    sprintf (arr, "%08X:", g);
+    snprintf (arr, 32, "%08X:", g);
   }
   else if (getLigatureScriptCode (g)==SD_AS_SHAPES)
   {
@@ -223,10 +224,10 @@ SUniFont::find (SS_UCS4 g)
     switch (gcode)
     {
     case 1:  /* 0xA000X001: */
-      sprintf (arr, "072A+0308-%s:", shapeVariants[fcode]);
+      snprintf (arr, 32, "072A+0308-%s:", shapeVariants[fcode]);
       break;
     default:
-      sprintf (arr, "%04X-%s:", gcode, shapeVariants[fcode]);
+      snprintf (arr, 32, "%04X-%s:", gcode, shapeVariants[fcode]);
     break;
     }
   }
@@ -250,7 +251,7 @@ SUniFont::find (SS_UCS4 g)
     int mid = (top + bottom) / 2;
     int index = nextIndex (mid, size, &gout); 
     
-      /* build the cahce */
+      /* build the cache */
     if (index >=0 && posWidth.get(gout) == 0)
     {
       /* 
