@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2020  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -659,6 +659,15 @@ SGCXXX
         }
     }
 
+- (void)otherMouseDown:(NSEvent *)evt {
+    NSPoint loc = [evt locationInWindow];
+    NSPoint point = [self convertPoint:loc fromView:nil];
+    if ([self cocoaEventOK]) {
+        self.cppWindow->listener->buttonPressed (self.cppWindow, 1,
+            (int)point.x, (int)point.y);
+    } 
+}
+
 - (void)mouseDown:(NSEvent *)evt {
     NSPoint loc = [evt locationInWindow];
     NSPoint point = [self convertPoint:loc fromView:nil];
@@ -1028,9 +1037,10 @@ void cocoaBitline (void* view, const SColor& fg, int x, int y,
     [cocoaConvertColor (fg) setStroke];
     NSBezierPath* path = [NSBezierPath bezierPath];
     [path setLineWidth:1];
-    [path setLineJoinStyle:NSBevelLineJoinStyle];
-    //[path setLineJoinStyle:NSMiterLineJoinStyle];
-    //[path setLineJoinStYLE:nsrOUndLineJoinStyle];
+    //[path setLineJoinStyle:NSLineJoinStyleMiter];
+    // our SRasterizer uses Bevel on Linux and Windows
+    [path setLineJoinStyle:NSLineJoinStyleBevel];
+    //[path setLineJoinStyle:NSLineJoinStyleRound];
     NSPoint from = NSMakePoint((double)x,(double)y);
     NSPoint to = NSMakePoint((double)tox,(double)toy);
     [path moveToPoint:from];
@@ -1104,7 +1114,9 @@ void cocoaEndImage (void* view) {
             if (cp.strokeColor != nil) {
                 [cp.strokeColor setStroke ];
                 [path setLineWidth: cp->strokeWidth];
-                [path setLineJoinStyle:NSRoundLineJoinStyle];
+                // https://developer.apple.com/documentation/appkit/nsroundlinejoinstyle?language=objc
+                //[path setLineJoinStyle:NSRoundLineJoinStyle];
+                [path setLineJoinStyle:NSLineJoinStyleRound];
                 [path stroke];
             }
         }
@@ -1197,7 +1209,9 @@ void cocoaStroke (void* view, const SPen& pen) {
         cw.currentPath.path];
 
     [path setLineWidth: cw.currentPath->strokeWidth];
-    [path setLineJoinStyle:NSRoundLineJoinStyle];
+    // https://developer.apple.com/documentation/appkit/nsroundlinejoinstyle?language=objc
+    //[path setLineJoinStyle:NSRoundLineJoinStyle];
+    [path setLineJoinStyle:NSLineJoinStyleRound];
     [path stroke];
 }
 
