@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2020  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -29,7 +29,7 @@
 #include "stoolkit/SStringVector.h"
 #include "stoolkit/SBinHashtable.h"
 #include "swindow/SAwt.h"
-#include "swindow/SGEngine.h"
+#include "swindow/SRasterizer.h"
 #include "swindow/SWindow.h"
 #include "swindow/SRedrawEvent.h"
 
@@ -116,6 +116,14 @@ SOSXImpl::getWindow (SWindowListener* l, const SString& name)
 SOSXWindow::SOSXWindow(const SString& n, SOSXImpl* i, void* _id) 
   : background ("white"), pen (SColor(0), SColor(0xffffffff)), name(n)
 {
+  modalFlag = false;
+  xpos = SD_WIN_X;
+  ypos = SD_WIN_Y;
+  xwidth = SD_WIN_W;
+  yheight = SD_WIN_H;
+
+  isCacheOn = true;
+
   currentFocusWindow = 0;
   shown = false;
   engine = 0;
@@ -156,7 +164,7 @@ SOSXWindow::hide ()
 }
 
 /**
- * This reqests a redraw, efficiently after all events got processed.
+ * This requests a redraw, efficiently after all events got processed.
  * @param clear is true if the window needs to be cleared before calling redraw.
  * @param x is the x origin of the event
  * @param y is the y origin of the event
@@ -308,7 +316,7 @@ SOSXWindow::bitpoints (const SColor& clr, const int* _x, const int* _y,
 }
 
 /**
- * Afetr this size things wont be cached.
+ * After this size things wont be cached.
  */
 void
 SOSXWindow::setPixmapCacheSize(unsigned int _size)
@@ -347,7 +355,7 @@ SOSXWindow::putImage (int _x, int _y, const SImage& im)
 bool
 SOSXWindow::beginImage (double _x, double _y, const SString& _id, const SColor& background)
 {
-  if (engine ==0) engine = new SGEngine();
+  if (engine ==0) engine = new SRasterizer();
   SString key;
   for (unsigned int i=0; i<_id.size(); i++) {
      unsigned char c = _id[i];
@@ -377,12 +385,12 @@ SOSXWindow::endImage ()
 }
 
 /**
- * FIXME: fill and return the resulting image for better cahcing.
+ * FIXME: fill and return the resulting image for better caching.
  */
 void
 SOSXWindow::fill (const SPen& _pen)
 {
-  if (engine ==0) engine = new SGEngine();
+  if (engine ==0) engine = new SRasterizer();
   if (pen != _pen)
   {
      pen = _pen;
@@ -392,8 +400,7 @@ SOSXWindow::fill (const SPen& _pen)
 
 void
 SOSXWindow::stroke (const SPen& _pen) {
-   if (engine ==0) engine = new SGEngine();
-   if (engine ==0) engine = new SGEngine();
+   if (engine ==0) engine = new SRasterizer();
    pen = _pen;
    cocoaStroke (cocoaWindow, pen);
 }
@@ -454,35 +461,35 @@ SOSXWindow::closepath()
 void
 SOSXWindow::rotate (double angle)
 {
-  if (engine ==0) engine = new SGEngine();
+  if (engine ==0) engine = new SRasterizer();
   engine->rotate (angle);
 }
 
 void
 SOSXWindow::scale (double x, double y)
 {
-  if (engine ==0) engine = new SGEngine();
+  if (engine ==0) engine = new SRasterizer();
   engine->scale (x, y);
 }
 
 void
 SOSXWindow::translate (double x, double y)
 {
-  if (engine ==0) engine = new SGEngine();
+  if (engine ==0) engine = new SRasterizer();
   engine->translate (x, y);
 }
 
 void
 SOSXWindow::pushmatrix()
 {
-  if (engine ==0) engine = new SGEngine();
+  if (engine ==0) engine = new SRasterizer();
   engine->pushmatrix();
 }
 
 void
 SOSXWindow::popmatrix()
 {
-  if (engine ==0) engine = new SGEngine();
+  if (engine ==0) engine = new SRasterizer();
   engine->popmatrix();
 }
 
@@ -518,7 +525,7 @@ SOSXWindow::copy (int _x, int _y, unsigned int _width, unsigned int _height,
 }
 
 /**
- * Assign a rectangualr clip area. Everithing outside this area will be clipped.
+ * Assign a rectangualr clip area. Everything outside this area will be clipped.
  */
 void
 SOSXWindow::setClippingArea (int _x, int _y, unsigned int _width, unsigned int _height)
@@ -543,14 +550,16 @@ SOSXWindow::wait ()
     cocoaWait (cocoaWindow);
 }
 
+/* isPrimary unused - all true */
 SString
-SOSXWindow::getClipUTF8()
+SOSXWindow::getClipUTF8(bool isPrimary)
 {
    return SString(cocoaGetClipboard ());
 }
 
+/* isPrimary unused - all true */
 void
-SOSXWindow::putClipUTF8(const SString& utf8)
+SOSXWindow::putClipUTF8(const SString& utf8, bool isPrimary)
 {
   name = utf8;
   char* cname = name.cString();
@@ -592,6 +601,8 @@ SOSXWindow::setDroppable (const SStringVector& targets) {
 void
 SOSXWindow::setModal (SWindow* _parent, bool decorated)
 {
+   /* CHECKME */
+   modalFlag = true;
    cocoaSetModal (cocoaWindow, ((SOSXWindow*)_parent)->cocoaWindow, decorated);
 }
 
@@ -882,3 +893,20 @@ bool
 SOSXWindow::commitInputMethod() {
     return cocoaCommitMacKeyboard (cocoaWindow);
 }
+
+// From virtual SCanvas.
+bool
+SOSXWindow::cacheOn(bool on)
+{
+  bool old = isCacheOn;
+  isCacheOn = on;
+  return old;
+}
+
+SS_Matrix2D
+SOSXWindow::getCurrentMatrix() const
+{
+  if (engine!=0) return engine->getCurrentMatrix();
+  return SS_Matrix2D();
+}
+
