@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -53,6 +53,9 @@ class SW32Window : public SWindow
 public:
   SW32Window(const SString& n, SW32Impl* i, long _id);
   virtual ~SW32Window();
+  virtual bool isShown () { return shown; }
+  virtual bool isModal () { return modalFlag; }
+  virtual void setModal (SWindow*w, bool decorated);
 
   /* windowing */
   virtual void show ();
@@ -79,14 +82,16 @@ public:
   virtual void removeClippingArea ();
 
 
-  virtual SString  getClipUTF8();
-  virtual void putClipUTF8(const SString& utf8);
+  virtual SString  getClipUTF8(bool isPrimary=true);
+  virtual void putClipUTF8(const SString& utf8, bool isPrimary=true);
 
   virtual void getKeyboardFocus();
   virtual void addAccelerator (const SAccelerator& a, 
       SAcceleratorListener* l);
   virtual void removeAccelerator (const SAccelerator& a,
       SAcceleratorListener* l);
+  /* x11,mac */
+  virtual void setDroppable (const SStringVector& targets) {}
 
   virtual bool startInputMethod (const SString& name, const SProperties& prop, SPreEditor* preEditor);
   virtual void stopInputMethod ();
@@ -112,6 +117,10 @@ public:
   virtual void rotate (double angle);
   virtual bool isVisible ();
 
+  /* SCanvas virtual. */
+  virtual bool cacheOn (bool on=true);
+  virtual SS_Matrix2D  getCurrentMatrix() const;
+
   virtual void putImage (int x, int y, const SImage& image);
   virtual void bitfill (const SColor& bg, int x, int y, 
         unsigned int width, unsigned int height);
@@ -119,7 +128,6 @@ public:
   virtual void bitpoint (const SColor& fg, int x, int y);
   virtual void bitpoints (const SColor& fg, const int* x, const int* y, 
          unsigned int size);
-  virtual void setModal (SWindow*w, bool decorated);
 
   static void setPixmapCacheSize(unsigned int _size);
   static void setPixmapCacheOn (bool _on);
@@ -156,11 +164,56 @@ private:
   void dcout(bool wasin);
 
   void*   clipRegion;
-  SGEngine*     engine;
+  SRasterizer*     engine;
   SPen   pen;
   SW32Impl* impl;
   SString name;
   SString imname;
+
+protected:
+  /* From canvas. */
+  bool isCacheOn;
+  /* common */
+  bool    shown;
+  bool    modalFlag;
+
+  int     xpos;
+  int     ypos;
+  unsigned int xwidth;
+  unsigned int yheight;
+
+public:
+  /* mac input */
+  virtual bool commitInputMethod() {return false;}
+  /* native x11 font */
+  virtual void bitfont (const SPen& pen, double x, double y, void* native, char* data, unsigned int len) {}
+  /* x11 only */
+  virtual void setApplicationImage (const SImage& im) {};
+  /* return true if input method has a status area. */
+  virtual bool hasStatusArea () { return false; }
+
+  void setSize (unsigned int _width, unsigned int _height) {
+    xwidth =  _width;
+    yheight = _height;
+  }
+  void setPosition (int _posx, int _posy) {
+    xpos = _posx;
+    ypos = _posy;
+  }
+  virtual unsigned int getWidth() const {
+    return xwidth;
+  }
+  virtual unsigned int getHeight() const {
+    return yheight;
+  }
+  virtual int getPositionX() const {
+    return xpos;
+  }
+  virtual int getPositionY() const {
+    return ypos;
+  }
+
+
 };
 
 #endif /* SW32_h */
