@@ -32,7 +32,7 @@ SPixmapCache maskCache;
 SPixmapCache imageCache;
 
 /*
- * This is true if we actually use the pixmap cache to cahce 
+ * This is true if we actually use the pixmap cache to cache 
  * the SImage on the X Server itself.
  */
 #define SS_IMAGE_SIZE (32*32)
@@ -814,6 +814,7 @@ SX11Window::resize (unsigned int _width, unsigned int _height)
   if (_width == 0) _width = 1;
   if (_height == 0) _height = 1;
   XResizeWindow (impl->display, (Window) dbuffer[0].id, _width, _height);
+  XFlush(impl->display);
   setSize(_width, _height);
 }
 
