@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
+ *  GNU Copyright (C) 1997-2023  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -24,7 +24,7 @@
 #include "swindow/sx11/SX11Color.h"
 #include "swindow/sx11/SXInputMethod.h"
 
-#include "swindow/SGEngine.h"
+#include "swindow/SRasterizer.h"
 
 #include "stoolkit/SBinVector.h"
 #include "stoolkit/SBinHashtable.h"
@@ -71,6 +71,10 @@ class SX11Window : public SWindow
 public:
   SX11Window (const SString &name, SX11Impl* impl, long id);
   virtual ~SX11Window();
+  virtual bool isShown () { return shown; }
+  virtual bool isModal () { return modalFlag; }
+  virtual void setModal (SWindow*w, bool decorated);
+
 
   static void setPixmapCacheSize(unsigned int size);
   static void setPixmapCacheOn (bool isOn=true);
@@ -117,7 +121,7 @@ public:
   virtual void bitline (const SColor& fg, int x, int y, int tox, int toy);
   virtual void bitpoint (const SColor& fg, int x, int y);
   virtual void bitpoints (const SColor& fg, const int* x, const int* y, 
-         unsigned int size);
+         unsigned int arraySize);
   /*---------------- end of canvas ---------------*/
 
   virtual void setBackground(const SColor &color);
@@ -139,8 +143,8 @@ public:
   virtual bool hasStatusArea ();
   virtual bool isVisible ();
 
-  virtual SString  getClipUTF8();
-  virtual void putClipUTF8(const SString& utf8);
+  virtual SString  getClipUTF8(bool isPrimary=true);
+  virtual void putClipUTF8(const SString& utf8, bool isPrimary=true);
   virtual void setTitle (const SString& title);
 
   virtual void addAccelerator (const SAccelerator& a, SAcceleratorListener* l);
@@ -149,7 +153,7 @@ public:
   void _acceleratorReleased (const SAccelerator& a);
 
   /*------- xdnd -----------*/
-  void setDroppable (const SStringVector& targets);
+  virtual void setDroppable (const SStringVector& targets);
   const SStringVector& getDroppable() const;
 
   /* Xutf8LookupString needs this from input context */
@@ -160,9 +164,9 @@ public:
 
   SBinVector<Atom> targetAtoms;
   SStringVector    targets;
-  virtual void setModal (SWindow*w, bool decorated);
   virtual void center (SWindow* window);
   virtual void wait ();
+
   bool mapNotified;
   bool exposedOnce; // The first expose event in X11 gives old size.
   bool isChild;
@@ -189,11 +193,49 @@ private:
   SX11Impl*     impl;
   SPen		pen;
   bool 		clipped; /* gc is clipped */
-  SGEngine*     engine;
+  SRasterizer*     engine;
   // added in 2.8.2
   unsigned int     dbindex;
   SX11DoubleBuffer dbuffer[2];
   SX11Region       clipRegion;
+
+protected:
+  /* From canvas. */
+  bool isCacheOn;
+  /* common */
+  bool    shown;
+  bool    modalFlag;
+
+  int     xpos;
+  int     ypos;
+  unsigned int xwidth;
+  unsigned int yheight;
+
+public:
+  virtual bool commitInputMethod() {return false; }
+
+
+  void setSize (unsigned int _width, unsigned int _height) {
+    xwidth =  _width;
+    yheight = _height;
+  }
+  void setPosition (int _posx, int _posy) {
+    xpos = _posx;
+    ypos = _posy;
+  }
+
+  virtual unsigned int getWidth() const {
+    return xwidth;
+  }
+  virtual unsigned int getHeight() const {
+    return yheight;
+  }
+  virtual int getPositionX() const {
+    return xpos;
+  }
+  virtual int getPositionY() const {
+    return ypos;
+  }
 };
 
 #endif /* SX11Window_h */
